@@ -49,6 +49,8 @@ using bgeot::base_small_vector; /* special class for small (dim<16) vectors */
 using bgeot::base_node;  /* geometrical nodes(derived from base_small_vector)*/
 using bgeot::scalar_type; /* = double */
 using bgeot::size_type;   /* = unsigned long */
+using bgeot::short_type; 
+using bgeot::dim_type; 
 using bgeot::base_matrix; /* small dense matrix. */
 
 /* definition of some matrix/vector types. These ones are builtmayavi -d crack.vtk -f WarpVector -m BandedSurfaceMap -m Outline
@@ -98,7 +100,7 @@ struct crack_problem {
   base_small_vector translation;
 
   scalar_type residual;      /* max residual for the iterative solvers       */
-  scalar_type conv_max;
+  size_type conv_max;
   unsigned dir_with_mult, with_contact, invert_contact;
   
   std::string datafilename;
@@ -188,7 +190,7 @@ void crack_problem::init(void) {
   residual = PARAM.real_value("RESIDUAL");
   if (residual == 0.) residual = 1e-10;
   
-  bimaterial = PARAM.int_value("BIMATERIAL", "Bimaterial interface crack");
+  bimaterial = int(PARAM.int_value("BIMATERIAL", "Bimaterial interface crack"));
   all_dirichlet = PARAM.int_value("all_dirichlet", "Dirichlet condition");
   F11 = PARAM.real_value("F11","F11");
   F12 = PARAM.real_value("F12","F12");
@@ -201,11 +203,11 @@ void crack_problem::init(void) {
  
   if (bimaterial == 1){
     mu = PARAM.real_value("MU", "Lame coefficient mu"); 
-    lambda_up = PARAM.int_value("LAMBDA_UP", "Lame Coef");
-    lambda_down = PARAM.int_value("LAMBDA_DOWN", "Lame Coef");
+    lambda_up = PARAM.real_value("LAMBDA_UP", "Lame Coef");
+    lambda_down = PARAM.real_value("LAMBDA_DOWN", "Lame Coef");
     lambda = PARAM.real_value("LAMBDA", "Lame coefficient lambda");
-    mu_up = PARAM.int_value("MU_UP", "Lame Coef");
-    mu_down = PARAM.int_value("MU_DOWN", "Lame Coef");
+    mu_up = PARAM.real_value("MU_UP", "Lame Coef");
+    mu_down = PARAM.real_value("MU_DOWN", "Lame Coef");
     
   }
   else{
@@ -215,7 +217,7 @@ void crack_problem::init(void) {
   }
   
 
-  mf_u().set_qdim(N);
+  mf_u().set_qdim(dim_type(N));
 
 
   /* set the finite element on the mf_u */
@@ -237,12 +239,12 @@ void crack_problem::init(void) {
   mimbound.set_simplex_im(simp_ppi, sing_ppi);
   mf_pre_u.set_finite_element(mesh.convex_index(), pf_u);
   mf_mult.set_finite_element(mesh.convex_index(), pf_u);
-  mf_mult.set_qdim(N);
+  mf_mult.set_qdim(dim_type(N));
 
 
-  dir_with_mult = PARAM.int_value("DIRICHLET_VERSION");
-  with_contact = PARAM.int_value("WITH_CONTACT");
-  invert_contact = PARAM.int_value("INVERT_CONTACT");
+  dir_with_mult = unsigned(PARAM.int_value("DIRICHLET_VERSION"));
+  with_contact = unsigned(PARAM.int_value("WITH_CONTACT"));
+  invert_contact = unsigned(PARAM.int_value("INVERT_CONTACT"));
   
 
   /* set the finite element on mf_rhs (same as mf_u is DATA_FEM_TYPE is
@@ -386,8 +388,8 @@ bool crack_problem::solve(plain_vector &U) {
       cout<<"CASE OF BIMATERIAL CRACK  with lambda_up = "<<lambda_up
 	  <<" and lambda_down = "<<lambda_down<<endl;
       cout<<"_________________________________________________________"<<endl;
-      std::vector<float> bi_lambda(ELAS.lambda().mf().nb_dof());
-      std::vector<float> bi_mu(ELAS.lambda().mf().nb_dof());
+      std::vector<double> bi_lambda(ELAS.lambda().mf().nb_dof());
+      std::vector<double> bi_mu(ELAS.lambda().mf().nb_dof());
     
       cout<<"ELAS.lambda().mf().nb_dof()==="<<ELAS.lambda().mf().nb_dof()<<endl;
     
@@ -505,7 +507,7 @@ bool crack_problem::solve(plain_vector &U) {
   cout << "Refining process complete. The mesh contains now " <<  mesh.convex_index().size() << " convexes "<<endl;
   
   dal::bit_vector blocked_dof = mf_u().dof_on_set(5);
-  getfem::mesh_fem mf_printed(mesh, N), mf_printed_vm(mesh);
+  getfem::mesh_fem mf_printed(mesh, dim_type(N)), mf_printed_vm(mesh);
   std::string FEM_DISC = PARAM.string_value("FEM_DISC","fem disc ");
   mf_printed.set_finite_element(mesh.convex_index(),
 				getfem::fem_descriptor(FEM_DISC));
@@ -549,7 +551,7 @@ int main(int argc, char *argv[]) {
       getfem::mesh mcut;
       p.mls.global_cut_mesh(mcut);
       unsigned Q = p.mf_u().get_qdim();
-      getfem::mesh_fem mf(mcut, Q);
+      getfem::mesh_fem mf(mcut, dim_type(Q));
       mf.set_classical_discontinuous_finite_element(2, 0.001);
       // mf.set_finite_element
       //	(getfem::fem_descriptor("FEM_PK_DISCONTINUOUS(2, 2, 0.0001)"));
@@ -560,7 +562,7 @@ int main(int argc, char *argv[]) {
       getfem::stored_mesh_slice sl;
       getfem::mesh mcut_refined;
 
-      unsigned NX = p.PARAM.int_value("NX"), nn;
+      unsigned NX = unsigned(p.PARAM.int_value("NX")), nn;
       if (NX < 6) nn = 24;
       else if (NX < 12) nn = 8;
       else if (NX < 30) nn = 3;
@@ -568,7 +570,7 @@ int main(int argc, char *argv[]) {
 
       // choose an adequate slice refinement based on the distance to
       // the crack tip
-      std::vector<bgeot::short_type> nrefine(mcut.convex_index().last_true()+1);
+      std::vector<short_type> nrefine(mcut.convex_index().last_true()+1);
       for (dal::bv_visitor cv(mcut.convex_index()); !cv.finished(); ++cv) {
 	scalar_type dmin=0, d;
 	base_node Pmin,P;
@@ -579,10 +581,10 @@ int main(int argc, char *argv[]) {
 	}
 
 	if (dmin < 1e-5)
-	  nrefine[cv] = nn*8;
+	  nrefine[cv] = short_type(nn*8);
 	else if (dmin < .1) 
-	  nrefine[cv] = nn*2;
-	else nrefine[cv] = nn;
+	  nrefine[cv] = short_type(nn*2);
+	else nrefine[cv] = short_type(nn);
 	// if (dmin < .01)
 	//  cout << "cv: "<< cv << ", dmin = " << dmin << "Pmin=" << Pmin 
 	//       << " " << nrefine[cv] << "\n";
@@ -602,7 +604,7 @@ int main(int argc, char *argv[]) {
       mim_refined.set_integration_method(getfem::int_method_descriptor
 					 ("IM_TRIANGLE(6)"));
 
-      getfem::mesh_fem mf_refined(mcut_refined, Q);
+      getfem::mesh_fem mf_refined(mcut_refined, dim_type(Q));
       mf_refined.set_classical_discontinuous_finite_element(2, 0.0001);
       plain_vector W(mf_refined.nb_dof());
 
