@@ -143,7 +143,7 @@ struct crack_problem {
 std::string name_of_dof(getfem::pdof_description dof) {
   char s[200];
   sprintf(s, "UnknownDof[%p]", (void*)dof);
-  for (unsigned d = 0; d < 4; ++d) {
+  for (dim_type d = 0; d < 4; ++d) {
     if (dof == getfem::lagrange_dof(d)) {
       sprintf(s, "Lagrange[%d]", d); goto found;
     }
@@ -160,11 +160,11 @@ std::string name_of_dof(getfem::pdof_description dof) {
       sprintf(s, "Xfem[idx:%d]", int(dof_xfem_index(dof)));
     }
     
-    for (unsigned r = 0; r < d; ++r) {
+    for (dim_type r = 0; r < d; ++r) {
       if (dof == getfem::derivative_dof(d, r)) {
 	sprintf(s, "D_%c[%d]", "xyzuvw"[r], d); goto found;
       }
-      for (unsigned t = 0; t < d; ++t) {
+      for (dim_type t = 0; t < d; ++t) {
 	if (dof == getfem::second_derivative_dof(d, r, t)) {
 	  sprintf(s, "D2%c%c[%d]", "xyzuvw"[r], "xyzuvw"[t], d); 
 	  goto found;
@@ -196,14 +196,14 @@ void crack_problem::init(void) {
   cout << "FEM_TYPE="  << FEM_TYPE << "\n";
   cout << "INTEGRATION=" << INTEGRATION << "\n";
 
-  bimaterial = PARAM.int_value("BIMATERIAL", "bimaterial interface crack");
+  bimaterial = int(PARAM.int_value("BIMATERIAL", "bimaterial interface crack"));
   
   if (bimaterial == 1){
     mu = PARAM.real_value("MU", "Lame coefficient mu"); 
     mu_up = PARAM.real_value("MU_UP", "Lame coefficient mu"); 
     mu_down = PARAM.real_value("MU_DOWN", "Lame coefficient mu"); 
-    lambda_up = PARAM.int_value("LAMBDA_UP", "Lame Coef");
-    lambda_down = PARAM.int_value("LAMBDA_DOWN", "Lame Coef");
+    lambda_up = PARAM.real_value("LAMBDA_UP", "Lame Coef");
+    lambda_down = PARAM.real_value("LAMBDA_DOWN", "Lame Coef");
     lambda = PARAM.real_value("LAMBDA", "Lame coefficient lambda");
   }
   else{
@@ -214,11 +214,11 @@ void crack_problem::init(void) {
   
   
   spider.radius = PARAM.real_value("SPIDER_RADIUS","spider_radius");
-  spider.Nr = PARAM.int_value("SPIDER_NR","Spider_Nr ");
-  spider.Ntheta = PARAM.int_value("SPIDER_NTHETA","Ntheta ");
-  spider.K = PARAM.int_value("SPIDER_K","K ");
+  spider.Nr = unsigned(PARAM.int_value("SPIDER_NR","Spider_Nr "));
+  spider.Ntheta = unsigned(PARAM.int_value("SPIDER_NTHETA","Ntheta "));
+  spider.K = int(PARAM.int_value("SPIDER_K","K "));
   spider.theta0 = 0;
-  spider.bimat_enrichment = PARAM.int_value("SPIDER_BIMAT_ENRICHMENT","spider_bimat_enrichment");
+  spider.bimat_enrichment = int(PARAM.int_value("SPIDER_BIMAT_ENRICHMENT","spider_bimat_enrichment"));
 
   /* The following constants are taken from the Chang and Xu paper of 2007 
      titled The singular stress field and stress intensity factors of a crack 
@@ -297,9 +297,9 @@ void crack_problem::init(void) {
   GLOBAL_FUNCTION_MF = PARAM.string_value("GLOBAL_FUNCTION_MF");
   GLOBAL_FUNCTION_U = PARAM.string_value("GLOBAL_FUNCTION_U");
 
-  reference_test = PARAM.int_value("REFERENCE_TEST", "Reference test"); 
+  reference_test = int(PARAM.int_value("REFERENCE_TEST", "Reference test")); 
 
-  unsigned EXACT_SOL_NUM = PARAM.int_value("EXACT_SOL_NUM", "Exact solution function number"); 
+  unsigned EXACT_SOL_NUM = unsigned(PARAM.int_value("EXACT_SOL_NUM", "Exact solution function number")); 
   
 
   cutoff_func = PARAM.int_value("CUTOFF_FUNC", "cutoff function");
@@ -307,7 +307,7 @@ void crack_problem::init(void) {
   cutoff_radius = PARAM.real_value("CUTOFF", "Cutoff");
   cutoff_radius1 = PARAM.real_value("CUTOFF1", "Cutoff1");
   cutoff_radius0 = PARAM.real_value("CUTOFF0", "Cutoff0");
-  mf_u().set_qdim(N);
+  mf_u().set_qdim(dim_type(N));
 
   /* set the finite element on the mf_u */
   getfem::pfem pf_u = 
@@ -328,7 +328,7 @@ void crack_problem::init(void) {
   mf_pre_mortar.set_finite_element(mesh.convex_index(), 
 				   getfem::fem_descriptor(PARAM.string_value("MORTAR_FEM_TYPE")));
   mf_mult.set_finite_element(mesh.convex_index(), pf_u);
-  mf_mult.set_qdim(N);
+  mf_mult.set_qdim(dim_type(N));
   mf_partition_of_unity.set_classical_finite_element(1);
   
 //   if (enrichment_option == 3 || enrichment_option == 4) {
@@ -345,7 +345,7 @@ void crack_problem::init(void) {
 
   mixed_pressure =
     (PARAM.int_value("MIXED_PRESSURE","Mixed version or not.") != 0);
-  dir_with_mult = PARAM.int_value("DIRICHLET_VERSINO");
+  dir_with_mult = unsigned(PARAM.int_value("DIRICHLET_VERSINO"));
   if (mixed_pressure) {
     std::string FEM_TYPE_P  = PARAM.string_value("FEM_TYPE_P","FEM name P");
     mf_p.set_finite_element(mesh.convex_index(),
@@ -482,7 +482,7 @@ bool crack_problem::solve(plain_vector &U) {
   std::vector<getfem::pglobal_function> vfunc(4);
   if (!load_global_fun) {
     cout << "Using default singular functions\n";
-    for (size_type i = 0; i < vfunc.size(); ++i){
+    for (unsigned i = 0; i < vfunc.size(); ++i){
       /* use the singularity */
       getfem::abstract_xy_function *s = 
 	new getfem::crack_singular_xy_function(i);
@@ -491,7 +491,7 @@ bool crack_problem::solve(plain_vector &U) {
 	/* use the product of the singularity function
 	   with a cutoff */
 	getfem::abstract_xy_function *c = 
-	  new getfem::cutoff_xy_function(cutoff_func,
+	  new getfem::cutoff_xy_function(int(cutoff_func),
 					 cutoff_radius, 
 					 cutoff_radius1,cutoff_radius0);
 	s = new getfem::product_of_xy_functions(*s, *c);
@@ -537,7 +537,7 @@ bool crack_problem::solve(plain_vector &U) {
 	/* use the product of the enrichment function
 	   with a cutoff */
 	getfem::abstract_xy_function *c = 
-	  new getfem::cutoff_xy_function(cutoff_func,
+	  new getfem::cutoff_xy_function(int(cutoff_func),
 					 cutoff_radius, 
 					 cutoff_radius1,cutoff_radius0);
 	s = new getfem::product_of_xy_functions(*s, *c);
@@ -670,7 +670,7 @@ bool crack_problem::solve(plain_vector &U) {
 
       const getfem::mesh::ind_cv_ct cvs = mf_u().convex_to_dof(d);
       for (unsigned i=0; i < cvs.size(); ++i) {
-	unsigned cv = cvs[i];
+	size_type cv = cvs[i];
 	//if (pm_cvlist.is_in(cv)) flag1 = true; else flag2 = true;
 
 	getfem::pfem pf = mf_u().fem_of_element(cv);
@@ -683,7 +683,7 @@ bool crack_problem::solve(plain_vector &U) {
 	if (ld == unsigned(-1)) {
 	  cout << "DOF " << d << "NOT FOUND in " << cv << " BUG BUG\n";
 	} else {
-	  printf(" %3d:%.16s", cv, name_of_dof(pf->dof_types().at(ld)).c_str());
+	  printf(" %3d:%.16s", int(cv), name_of_dof(pf->dof_types().at(ld)).c_str());
 	}
       }
       printf("\n");
@@ -701,8 +701,8 @@ bool crack_problem::solve(plain_vector &U) {
     cout<<"______________________________________________________________________________"<<endl;
     cout<<"CASE OF BIMATERIAL CRACK  with lambda_up = "<<lambda_up<<" and lambda_down = "<<lambda_down<<endl;
     cout<<"______________________________________________________________________________"<<endl;
-    std::vector<float> bi_lambda(ELAS.lambda().mf().nb_dof());
-    std::vector<float> bi_mu(ELAS.lambda().mf().nb_dof());
+    std::vector<double> bi_lambda(ELAS.lambda().mf().nb_dof());
+    std::vector<double> bi_mu(ELAS.lambda().mf().nb_dof());
     
     cout<<"ELAS.lambda().mf().nb_dof()==="<<ELAS.lambda().mf().nb_dof()<<endl;
     
@@ -859,7 +859,7 @@ bool crack_problem::solve(plain_vector &U) {
     for (size_type d = 0; d < mf_u().nb_dof(); ++d) {
       if (M2(d,d) < 1e-10) {
 	cout << "  removing null mf_u() dof " << d << "\n";
-	unsigned n = gmm::mat_nrows(H);
+	size_type n = gmm::mat_nrows(H);
 	gmm::resize(H, n+1, gmm::mat_ncols(H));
 	H(n, d) = 1;
       }
@@ -887,7 +887,7 @@ bool crack_problem::solve(plain_vector &U) {
     {
       cout << "Exporting reference solution...";
       dal::bit_vector blocked_dof = mf_u().dof_on_set(5);
-      getfem::mesh_fem mf_refined(mesh, N);
+      getfem::mesh_fem mf_refined(mesh, dim_type(N));
       std::string FEM_DISC = PARAM.string_value("FEM_DISC","fem disc ");
       mf_refined.set_finite_element(mesh.convex_index(),
 				    getfem::fem_descriptor(FEM_DISC));
@@ -962,7 +962,7 @@ int main(int argc, char *argv[]) {
       getfem::mesh mcut;
       p.mls.global_cut_mesh(mcut);
       unsigned Q = p.mf_u().get_qdim();
-      getfem::mesh_fem mf(mcut, Q);
+      getfem::mesh_fem mf(mcut, dim_type(Q));
       mf.set_classical_discontinuous_finite_element(2, 0.001);
       // mf.set_finite_element
       //	(getfem::fem_descriptor("FEM_PK_DISCONTINUOUS(2, 2, 0.0001)"));
@@ -973,7 +973,7 @@ int main(int argc, char *argv[]) {
       getfem::stored_mesh_slice sl;
       getfem::mesh mcut_refined;
 
-      unsigned NX = p.PARAM.int_value("NX"), nn;
+      unsigned NX = unsigned(p.PARAM.int_value("NX")), nn;
 //  unsigned NX = (unsigned)sqrt(p.mesh.convex_index().card()); 
 //    unsigned nn;
       if (NX < 6) nn = 24;
@@ -993,10 +993,10 @@ int main(int argc, char *argv[]) {
 	}
 
 	if (dmin < 1e-5)
-	  nrefine[cv] = nn*8;
+	  nrefine[cv] = short_type(nn*8);
 	else if (dmin < .1) 
-	  nrefine[cv] = nn*2;
-	else nrefine[cv] = nn;
+	  nrefine[cv] = short_type(nn*2);
+	else nrefine[cv] = short_type(nn);
 	if (dmin < .01)
 	  cout << "cv: "<< cv << ", dmin = " << dmin << "Pmin=" << Pmin << " " << nrefine[cv] << "\n";
       }
@@ -1015,7 +1015,7 @@ int main(int argc, char *argv[]) {
       mim_refined.set_integration_method(getfem::int_method_descriptor
 					 ("IM_TRIANGLE(6)"));
 
-      getfem::mesh_fem mf_refined(mcut_refined, Q);
+      getfem::mesh_fem mf_refined(mcut_refined, dim_type(Q));
       mf_refined.set_classical_discontinuous_finite_element(2, 0.001);
       plain_vector W(mf_refined.nb_dof());
 
@@ -1023,7 +1023,7 @@ int main(int argc, char *argv[]) {
 
 
 #ifdef VALIDATE_XFEM
-      p.exact_sol.mf.set_qdim(Q);
+      p.exact_sol.mf.set_qdim(dim_type(Q));
       assert(p.exact_sol.mf.nb_dof() == p.exact_sol.U.size());
       plain_vector EXACT(mf_refined.nb_dof());
       getfem::interpolation(p.exact_sol.mf, mf_refined, 
