@@ -17,6 +17,15 @@
 // along  with  this program;  if not, write to the Free Software Foundation,
 // Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA.
 //
+// As a special exception, you  may use  this file  as it is a part of a free
+// software  library  without  restriction.  Specifically,  if   other  files
+// instantiate  templates  or  use macros or inline functions from this file,
+// or  you compile this  file  and  link  it  with other files  to produce an
+// executable, this file  does  not  by itself cause the resulting executable
+// to be covered  by the GNU Lesser General Public License.  This   exception
+// does not  however  invalidate  any  other  reasons why the executable file
+// might be covered by the GNU Lesser General Public License.
+//
 //===========================================================================
 
 #include "getfem/getfem_config.h"
@@ -319,8 +328,8 @@ void bilaplacian_mortar_problem::init(void) {
     
    /* read the parameters   */
   epsilon = PARAM.real_value("EPSILON", "thickness") ;
-  int dv = PARAM.int_value("DIRICHLET_VERSION", "Dirichlet version");
-  int mv = PARAM.int_value("MORTAR_VERSION", "Mortar version");
+  int dv = int(PARAM.int_value("DIRICHLET_VERSION", "Dirichlet version"));
+  int mv = int(PARAM.int_value("MORTAR_VERSION", "Mortar version"));
   dirichlet_version = getfem::constraints_type(dv);
   mortar_version = getfem::constraints_type(mv);
   datafilename=PARAM.string_value("ROOTFILENAME","Base name of data files.");
@@ -813,7 +822,7 @@ bool bilaplacian_mortar_problem::solve(plain_vector &U) {
       if (M2(d,d) < PARAM.real_value("SEUIL")) {
 	cout << "  removing null mf_u dof " << d << " @ " << 
 	  mf_u.point_of_dof(d) << "\n";	
-	unsigned n = gmm::mat_nrows(H);
+	size_type n = gmm::mat_nrows(H);
 	gmm::resize(H, n+1, gmm::mat_ncols(H));
 	H(n, d) = 1;
       }
