@@ -17,14 +17,14 @@
 // along  with  this program;  if not, write to the Free Software Foundation,
 // Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA.
 //
-// As a special exception, you may use this file as part of a free software
-// library without restriction.  Specifically, if other files instantiate
-// templates or use macros or inline functions from this file, or you compile
-// this file and link it with other files to produce an executable, this
-// file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however
-// invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.
+// As a special exception, you  may use  this file  as it is a part of a free
+// software  library  without  restriction.  Specifically,  if   other  files
+// instantiate  templates  or  use macros or inline functions from this file,
+// or  you compile this  file  and  link  it  with other files  to produce an
+// executable, this file  does  not  by itself cause the resulting executable
+// to be covered  by the GNU Lesser General Public License.  This   exception
+// does not  however  invalidate  any  other  reasons why the executable file
+// might be covered by the GNU Lesser General Public License.
 //
 //===========================================================================
 
@@ -440,6 +440,30 @@ namespace getfem {
   }
 
 
+  /** 
+     generic mass matrix assembly with an additional parameter
+     (on the whole mesh or on the specified boundary) 
+     @ingroup asm
+   */
+  template<typename MAT, typename VECT>
+  void asm_mass_matrix_param
+  (MAT &M, const mesh_im &mim, const mesh_fem &mf_u1, const mesh_fem &mf_u2,
+   const mesh_fem &mf_data, const VECT &F,
+   const mesh_region &rg = mesh_region::all_convexes()) {
+    generic_assembly assem;
+    if (mf_u1.get_qdim() == 1 && mf_u2.get_qdim() == 1)
+      assem.set("F=data(#3);M(#1,#2)+=comp(Base(#1).Base(#2).Base(#3))(:,:,i).F(i)");
+    else
+      assem.set("F=data(#3);M(#1,#2)+=comp(vBase(#1).vBase(#2).Base(#3))(:,i,:,i,j).F(j);");
+    assem.push_mi(mim);
+    assem.push_mf(mf_u1);
+    assem.push_mf(mf_u2);
+    assem.push_mf(mf_data);
+    assem.push_mat(const_cast<MAT &>(M));
+    assem.push_data(F);
+    assem.assembly(rg);
+  }
+
   /** 
       source term (for both volumic sources and boundary (Neumann) sources).
       @ingroup asm
@@ -912,7 +936,7 @@ namespace getfem {
     for (mr_visitor v(region); !v.finished(); v.next()) {
       GMM_ASSERT1(v.is_face(), "attempt to impose a dirichlet "
 		  "on the interior of the domain!");
-      size_type cv = v.cv(), f = v.f();
+      size_type cv = v.cv(); short_type f = v.f();
 
       GMM_ASSERT1(mf_u.convex_index().is_in(cv) &&
 		  mf_r.convex_index().is_in(cv) &&
@@ -1154,7 +1178,8 @@ namespace getfem {
     /* step 2 : simplification of simple dirichlet conditions */
     if (&mf_r == &mf_h) {
       for (mr_visitor v(region); !v.finished(); v.next()) {
-	size_type cv = v.cv(), f = v.f();
+	size_type cv = v.cv();
+	short_type f = v.f();
 
 	GMM_ASSERT1(mf_u.convex_index().is_in(cv) &&
 		    mf_r.convex_index().is_in(cv), 
