@@ -17,14 +17,14 @@
 // along  with  this program;  if not, write to the Free Software Foundation,
 // Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA.
 //
-// As a special exception, you may use this file as part of a free software
-// library without restriction.  Specifically, if other files instantiate
-// templates or use macros or inline functions from this file, or you compile
-// this file and link it with other files to produce an executable, this
-// file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however
-// invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.
+// As a special exception, you  may use  this file  as it is a part of a free
+// software  library  without  restriction.  Specifically,  if   other  files
+// instantiate  templates  or  use macros or inline functions from this file,
+// or  you compile this  file  and  link  it  with other files  to produce an
+// executable, this file  does  not  by itself cause the resulting executable
+// to be covered  by the GNU Lesser General Public License.  This   exception
+// does not  however  invalidate  any  other  reasons why the executable file
+// might be covered by the GNU Lesser General Public License.
 //
 //===========================================================================
 
@@ -74,7 +74,8 @@ namespace getfem {
      *        into account, else test them on the frontiere convexes.
      */
     void distribute(bool extrapolation = false);
-    mesh_trans_inv(const mesh &m) : bgeot::geotrans_inv(1E-12), msh(m) {}
+    mesh_trans_inv(const mesh &m, double EPS_ = 1E-12)
+      : bgeot::geotrans_inv(EPS_), msh(m) {}
   private :
     void add_point_with_id(base_node, size_type) {}
   };
@@ -208,7 +209,8 @@ namespace getfem {
   */
   template<typename VECTU, typename VECTV>
   void interpolation(const mesh_fem &mf_source, const mesh_fem &mf_target,
-		     const VECTU &U, VECTV &V, bool extrapolation = false);
+		     const VECTU &U, VECTV &V, bool extrapolation = false,
+		     double EPS = 1E-10);
 
   /**
      @brief Build the interpolation matrix of mf_source on mf_target.
@@ -219,7 +221,7 @@ namespace getfem {
    */
   template<typename MAT>
   void interpolation(const mesh_fem &mf_source, const mesh_fem &mf_target,
-		     MAT &M, bool extrapolation = false);
+		     MAT &M, bool extrapolation = false, double EPS = 1E-10);
 
 
   /* --------------------------- Implementation ---------------------------*/
@@ -240,8 +242,8 @@ namespace getfem {
 				 MAT &M, int version) {
     typedef typename gmm::linalg_traits<VECTU>::value_type T;
     base_matrix G;
-    size_type qdim = mf_source.get_qdim();
-    size_type qqdim = gmm::vect_size(U)/mf_source.nb_dof();
+    dim_type qdim = mf_source.get_qdim();
+    dim_type qqdim = dim_type(gmm::vect_size(U)/mf_source.nb_dof());
     std::vector<T> val(qdim);
     std::vector<std::vector<T> > coeff;
     std::vector<size_type> dof_source;
@@ -331,8 +333,8 @@ namespace getfem {
 
     typedef typename gmm::linalg_traits<VECTU>::value_type T;
     const mesh &msh(mf_source.linked_mesh());
-    size_type qdim_s = mf_source.get_qdim();
-    size_type qqdim = gmm::vect_size(U)/mf_source.nb_dof();
+    dim_type qdim_s = mf_source.get_qdim();
+    dim_type qqdim = dim_type(gmm::vect_size(U)/mf_source.nb_dof());
 
     mti.distribute(extrapolation);
     std::vector<size_type> itab;    
@@ -431,10 +433,11 @@ namespace getfem {
   template<typename VECTU, typename VECTV, typename MAT>
     void interpolation(const mesh_fem &mf_source, const mesh_fem &mf_target,
 		       const VECTU &U, VECTV &V, MAT &M,
-		       int version, bool extrapolation = false) {
+		       int version, bool extrapolation = false,
+		       double EPS = 1E-10) {
 
     const mesh &msh(mf_source.linked_mesh());
-    getfem::mesh_trans_inv mti(msh);
+    getfem::mesh_trans_inv mti(msh, EPS);
     size_type qdim_s = mf_source.get_qdim(), qdim_t = mf_target.get_qdim();
     GMM_ASSERT1(qdim_s == qdim_t || qdim_t == 1,
 		"Attempt to interpolate a field of dimension "
@@ -455,7 +458,8 @@ namespace getfem {
 
   template<typename VECTU, typename VECTV>
   void interpolation(const mesh_fem &mf_source, const mesh_fem &mf_target,
-		     const VECTU &U, VECTV &V, bool extrapolation) {
+		     const VECTU &U, VECTV &V, bool extrapolation,
+		     double EPS = 1E-10) {
     base_matrix M;
     GMM_ASSERT1((gmm::vect_size(U) % mf_source.nb_dof()) == 0
 		&& (gmm::vect_size(V) % mf_target.nb_dof()) == 0
@@ -464,12 +468,12 @@ namespace getfem {
       interpolation_same_mesh(mf_source, mf_target, U, V, M, 0);
     }
     else 
-      interpolation(mf_source, mf_target, U, V, M, 0, extrapolation);
+      interpolation(mf_source, mf_target, U, V, M, 0, extrapolation, EPS);
   }
 
   template<typename MAT>
   void interpolation(const mesh_fem &mf_source, const mesh_fem &mf_target,
-		     MAT &M, bool extrapolation) {
+		     MAT &M, bool extrapolation, double EPS = 1E-10) {
     GMM_ASSERT1(mf_source.nb_dof() == gmm::mat_ncols(M)
 		&& (gmm::mat_nrows(M) % mf_target.nb_dof()) == 0
 		&& gmm::mat_nrows(M) != 0, "Dimensions mismatch");
@@ -478,7 +482,7 @@ namespace getfem {
       interpolation_same_mesh(mf_source, mf_target, U, V, M, 1);
     }
     else 
-      interpolation(mf_source, mf_target, U, V, M, 1, extrapolation);
+      interpolation(mf_source, mf_target, U, V, M, 1, extrapolation, EPS);
   }
 
   //
