@@ -39,6 +39,8 @@ using bgeot::base_small_vector; /* special class for small (dim<16) vectors */
 using bgeot::base_node;  /* geometrical nodes(derived from base_small_vector)*/
 using bgeot::scalar_type; /* = double */
 using bgeot::size_type;   /* = unsigned long */
+using bgeot::short_type; 
+using bgeot::dim_type;
 using bgeot::base_matrix; /* small dense matrix. */
 
 /* definition of some matrix/vector types. These ones are built
@@ -133,8 +135,8 @@ void plate_problem::init(void) {
 
   cout << "MITC = " ;
   if (mitc) cout << "true \n" ; else cout << "false \n" ;
-  sol_ref = (PARAM.int_value("SOL_REF") ) ;
-  study_flag = (PARAM.int_value("STUDY_FLAG") ) ;
+  sol_ref = int((PARAM.int_value("SOL_REF")));
+  study_flag = int(PARAM.int_value("STUDY_FLAG") ) ;
   eta = (PARAM.real_value("ETA") );
   N_Four = (PARAM.int_value("N_Four") ) ;
   
@@ -165,14 +167,14 @@ void plate_problem::init(void) {
      gmm::resize( u3_Four, N_Four, N_Four) ;
      base_matrix Jmn(3, 3) ; 
      base_small_vector Bmn(3), Xmn(3) ; 
-     scalar_type det_Jmn, E, nu, A, B, e2, Pmn ;
+     scalar_type E, nu, A, B, e2, Pmn ;
      E = 4.*mu*(mu+lambda) / (2. * mu + lambda);
      nu = lambda / (2. * mu + lambda);
      e2 = epsilon * epsilon ;
      for(size_type i = 0 ; i < N_Four ; i++) {
         for(size_type j = 0 ; j < N_Four ; j++) {
-	   A = (j + 1) * M_PI / LX ; 
-	   B = (i + 1) * M_PI / LY ; 
+	   A = scalar_type(j + 1) * M_PI / LX ; 
+	   B = scalar_type(i + 1) * M_PI / LY ; 
 	   Jmn(0, 0) = 2. * A * A / (1. - nu) + B * B + 3. / e2   ;
 	   Jmn(0, 1) = A * B * (1. +nu) / (1. - nu) ;
 	   Jmn(0, 2) = A * 3. / e2 ;
@@ -186,7 +188,7 @@ void plate_problem::init(void) {
 	   
 	   // calcul du dveloppement de Fourrier du chargement :
 	   if ( ( (i + 1) % 2 == 1 ) && ( (j + 1) % 2 == 1) ) {
-	      Pmn =  16. * pressure / ( (i + 1) * (j + 1) * M_PI * M_PI) ; }
+	      Pmn =  16. * pressure / ( scalar_type(i + 1) * scalar_type(j + 1) * M_PI * M_PI) ; }
 	   else {
 	      Pmn = 0. ; }	      
 	   Bmn[0] = 0. ;
@@ -225,8 +227,8 @@ void plate_problem::init(void) {
         }
      }
 
-  mf_ut.set_qdim(N);
-  mf_theta.set_qdim(N);
+  mf_ut.set_qdim(dim_type(N));
+  mf_theta.set_qdim(dim_type(N));
 
   /* set the finite element on the mf_u */
   getfem::pfem pf_ut = getfem::fem_descriptor(FEM_TYPE_UT);
@@ -328,8 +330,8 @@ base_small_vector plate_problem::theta_exact(base_node P) {
      theta[1] = 0. ;
      for(size_type i = 0 ; i < N_Four ; i ++) {
         for(size_type j = 0 ; j < N_Four ; j ++) {
-	   theta[0] += theta1_Four(i, j) * cos( (j + 1) * M_PI * P[0] / LX ) * sin( (i + 1) * M_PI * P[1] / LY ) ;
-	   theta[0] += theta2_Four(i, j) * sin( (j + 1) * M_PI * P[0] / LX ) * cos( (i + 1) * M_PI * P[1] / LY ) ;
+	   theta[0] += theta1_Four(i, j) * cos( scalar_type(j + 1) * M_PI * P[0] / LX ) * sin( scalar_type(i + 1) * M_PI * P[1] / LY ) ;
+	   theta[0] += theta2_Four(i, j) * sin( scalar_type(j + 1) * M_PI * P[0] / LX ) * cos( scalar_type(i + 1) * M_PI * P[1] / LY ) ;
            }
         }
      }
@@ -357,7 +359,7 @@ scalar_type plate_problem::u3_exact(base_node P) {
        u3_local = 0. ;
        for(size_type i = 0 ; i < N_Four ; i ++) {
           for(size_type j = 0 ; j < N_Four ; j ++) 
-	     u3_local += u3_Four(i, j) * sin( (j + 1) * M_PI * P[0] / LX ) * sin( (i + 1) * M_PI * P[1] / LY ) ;
+	     u3_local += u3_Four(i, j) * sin( scalar_type(j + 1) * M_PI * P[0] / LX ) * sin( scalar_type(i + 1) * M_PI * P[1] / LY ) ;
 	     }
        return (u3_local) ;
        break ; 
